import React from 'react';
import { TouchableOpacity, Text } from 'react-native';
import { SvgProps } from 'react-native-svg';
import { Colors } from 'src/theme';

interface MapButtonProps {
  onPress: () => void;
  icon: React.ComponentType<SvgProps> | null;
  text: string;
}

const MapButton: React.FC<MapButtonProps> = ({ onPress, icon: Icon, text }) => {
  return (
    <TouchableOpacity
      style={{
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: Colors.WHITE,
        borderRadius: 17,
        paddingHorizontal: 10,
        paddingVertical: 6,
        gap: 4,
        shadowColor: '#000',
        shadowOffset: {
          width: 0,
          height: 1
        },
        shadowOpacity: 0.25,
        shadowRadius: 1.5,
        elevation: 2,
        marginVertical: 4
      }}
      onPress={onPress}
    >
      {Icon && <Icon fill={Colors.DARK_BLUE} width={16} height={16} />}
      <Text
        style={{
          color: Colors.DARK_BLUE,
          fontSize: 12,
          fontWeight: '600'
        }}
      >
        {text}
      </Text>
    </TouchableOpacity>
  );
};

export default MapButton;
